@@ -1,15 +1,14 @@
-import os
-import re
 import logging
 import mimetypes
+import os
+import re
 from base64 import b64encode
-
 from django.conf import settings
 from django.contrib.staticfiles import finders
 from django.core.files.base import File, ContentFile
+from django.core.mail.message import EmailMultiAlternatives, EmailMessage
 from django.db.models.fields.files import FieldFile
 from django.template import engines, loader
-from django.core.mail.message import EmailMultiAlternatives, EmailMessage
 
 from rh_email_tpl.utils.translation import custom_translation_override
 
@@ -23,6 +22,7 @@ class RHEmailMessage:
     generate_text_from_html = False
     email_multi_alternatives_class = EmailMultiAlternatives
     reply_to = []
+    sender_display_label = None
 
     def __init__(
         self,
@@ -38,8 +38,9 @@ class RHEmailMessage:
         reply_to=None,
         attached_files=None,
         extra_email_kwargs=None,
+        sender_display_label=None,
         *args,
-        **kwargs
+        **kwargs,
     ):
         if args:
             logger.error("Received unsupported args: %s", args, extra={"args": args})
@@ -58,6 +59,7 @@ class RHEmailMessage:
         self.reply_to = reply_to
         self.attached_files = attached_files
         self.extra_email_kwargs = extra_email_kwargs
+        self.sender_display_label = sender_display_label
 
     def get_context_data(self):
         return self.context or {}
@@ -87,6 +89,16 @@ class RHEmailMessage:
     def get_subject(self):
         return self.subject
 
+    def get_sender_display_label(self):
+        return self.sender_display_label
+
+    def get_final_from_email(self):
+        sender_display_label = self.get_sender_display_label()
+        from_email = self.get_from_email()
+        if sender_display_label:
+            return f"{sender_display_label} <{from_email}>"
+        return from_email
+
     def get_template_html(self):
         return self.template_html
 
@@ -184,7 +196,7 @@ class RHEmailMessage:
         msg = self.email_multi_alternatives_class(
             subject=self.get_subject(),
             body=self.get_body_text(),
-            from_email=self.get_from_email(),
+            from_email=self.get_final_from_email(),
             to=self._clean_address_list(self.get_to()),
             cc=self._clean_address_list(self.get_cc()),
             bcc=self._clean_address_list(self.get_bcc()),
